/**
 * @description: 封装一个类，能给 localStorage 存储的值设置过期时间，如给存储在本地的用于登录 token 设置过期时间
 */
class Storage {
  constructor(name) {
    this.name = 'storage';
  }
  /**
   * @description: 设置缓存
   * @param {*} keyName: 要创建或更新的键名
   * @param {*} keyValue: 要创建或更新的键名对应的值
   * @param {*} expires: 过期时间，单位：秒
   * @return {*}
   */
  setItem(keyName, keyValue, expires = null) {
    const options = {
      keyValue: keyValue,
      expires: expires ? expires * 1000 : null,
      startTime: expires ? new Date().getTime() : 0
    }
    localStorage.setItem(keyName, JSON.stringify(options));
  }
  /**
   * @description: 返回对应键名的值
   * @param {*} keyName: 一个包含键名的 DOMString
   * @return {*} 一个 DOMString，键名对应的值。如果键名不存在于存储中，则返回 null
   */
  getItem(keyName) {
    let item = localStorage.getItem(keyName);
    if (item === null) return null;
    item = JSON.parse(item);
    //如果有 startTime 的值，说明设置了失效时间
    if (item.startTime) {
      const date = new Date().getTime();
      //何时将值取出减去刚存入的时间，与item.expires比较，如果大于就是过期了，如果小于或等于就还没过期
      if (date - item.startTime > item.expires) {
        //缓存过期，清除缓存，返回false
        localStorage.removeItem(keyName);
        return null;
      } else {
        //缓存未过期，返回值
        return item.keyValue;
      }
    } else {
      //如果没有设置失效时间，直接返回值
      return item.keyValue;
    }
  }
  /**
   * @description: 接受一个键名作为参数，从 localStorage 对象中删除该键名
   * @param {*} keyName: 想要移除的键名
   * @return {*}
   */
  removeItem(keyName) {
    localStorage.removeItem(keyName);
  }
  /**
   * @description: 清空存储对象里所有的键值
   * @return {*}
   */
  clear() {
    localStorage.clear();
  }
}
export default Storage
